"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const deepMerge = require("deepmerge");
const plugin_content_docs_1 = require("@docusaurus/plugin-content-docs");
const logger = process.env.DEBUG ? console : {
    log: () => { },
};
function pluginContentDocs(context, options) {
    if (options.length === 0) {
        throw new Error("No configurations was found");
    }
    const contentDocs = options.map((opts) => (Object.assign({ id: opts.id }, plugin_content_docs_1.default(context, opts))));
    return {
        name: "docusaurus-plugin-content-docs",
        getThemePath() {
            return contentDocs[0].getThemePath();
        },
        // @todo Add support for extendCli
        // extendCli
        getPathsToWatch() {
            const paths = contentDocs
                .filter((c) => c && c.getPathsToWatch)
                .reduce((pths, c) => {
                if (c && c.getPathsToWatch) {
                    return pths.concat(pths, c.getPathsToWatch());
                }
                return pths;
            }, []);
            return paths;
        },
        getClientModules() {
            const modules = [];
            let shouldIncludeAdmonitions = false;
            options.forEach(opts => {
                if (opts.admonitions) {
                    shouldIncludeAdmonitions = true;
                }
            });
            if (shouldIncludeAdmonitions) {
                modules.push(require.resolve("remark-admonitions/styles/infima.css"));
            }
            return modules;
        },
        loadContent() {
            return __awaiter(this, void 0, void 0, function* () {
                // const contents: MultiLoadedContent[] = [];
                const contents = yield Promise.all(contentDocs.map((d) => __awaiter(this, void 0, void 0, function* () {
                    if (!d || !d.loadContent)
                        return;
                    const c = yield d.loadContent();
                    if (c === null)
                        return;
                    return Object.assign({ id: d.id }, c);
                })));
                return contents.filter((c) => c);
            });
        },
        contentLoaded({ content, actions }) {
            return __awaiter(this, void 0, void 0, function* () {
                yield Promise.all(contentDocs.map((c) => __awaiter(this, void 0, void 0, function* () {
                    if (c && c.contentLoaded && content) {
                        const cntnt = content.find((cd) => cd.id === c.id);
                        if (cntnt) {
                            return c.contentLoaded({
                                content: cntnt,
                                actions: actions,
                            });
                        }
                    }
                })));
            });
        },
        configureWebpack(_config, isServer, utils) {
            const webpack = contentDocs.reduce((contents, d) => {
                if (!d || !d.configureWebpack)
                    return contents;
                return deepMerge(contents, d.configureWebpack(_config, isServer, utils));
            }, {});
            return webpack;
        },
    };
}
exports.default = pluginContentDocs;
//# sourceMappingURL=index.js.map